'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

/**
 * useStepper() - Build your stepper component.
 */

var useStepper = function useStepper(props) {
  if (props === void 0) {
    props = {
      maxStep: 1
    };
  }

  var _props = props,
      maxStep = _props.maxStep,
      _props$activeStep = _props.activeStep,
      activeStep = _props$activeStep === void 0 ? 1 : _props$activeStep,
      _props$loop = _props.loop,
      loop = _props$loop === void 0 ? false : _props$loop,
      _props$triggerGoToPre = _props.triggerGoToPrevStep,
      triggerDefaulGoToPrevStep = _props$triggerGoToPre === void 0 ? {} : _props$triggerGoToPre,
      _props$triggerGoToNex = _props.triggerGoToNextStep,
      triggerDefaulGoToNextStep = _props$triggerGoToNex === void 0 ? {} : _props$triggerGoToNex,
      _props$triggerResetSt = _props.triggerResetStep,
      triggerDefaulResetStep = _props$triggerResetSt === void 0 ? {} : _props$triggerResetSt;

  var _useState = react.useState(activeStep),
      currentStep = _useState[0],
      setCurrentStep = _useState[1];

  var _useState2 = react.useState(true),
      isFirstStep = _useState2[0],
      setIsFirstStep = _useState2[1];

  var _useState3 = react.useState(false),
      isLastStep = _useState3[0],
      setIsLastStep = _useState3[1];

  var triggerGoToPrevStepRef = react.useRef(null);
  var triggerGoToNextStepRef = react.useRef(null);
  var triggerResetStepRef = react.useRef(null);
  var canGoToPrevStep = react.useMemo(function () {
    return currentStep - 1 >= 1;
  }, [currentStep]);
  var canGoToNextStep = react.useMemo(function () {
    return currentStep + 1 <= maxStep;
  }, [currentStep]);
  var goToPrevStep = react.useCallback(function () {
    if (canGoToPrevStep) {
      setCurrentStep(function (step) {
        return step - 1;
      });
    } else {
      if (loop) {
        setCurrentStep(maxStep);
      }
    }
  }, [currentStep, maxStep]);
  var goToNextStep = react.useCallback(function () {
    if (canGoToNextStep) {
      setCurrentStep(function (step) {
        return step + 1;
      });
    } else {
      if (loop) {
        setCurrentStep(1);
      }
    }
  }, [currentStep]);
  var reset = react.useCallback(function () {
    setCurrentStep(1);
  }, []);
  var goToStep = react.useCallback(function (step) {
    if (step >= 1 && step <= maxStep) {
      setCurrentStep(step);
    }
  }, [maxStep]);
  react.useEffect(function () {
    setIsFirstStep(false);
    setIsLastStep(false);

    if (currentStep === 1) {
      setIsFirstStep(true);
    }

    if (currentStep === maxStep) {
      setIsLastStep(true);
    }

    return function () {
      setIsFirstStep(true);
      setIsLastStep(false);
    };
  }, [currentStep]);

  var triggerGoToPrevStep = _extends({
    onClick: function onClick() {
      goToPrevStep();
    }
  }, triggerDefaulGoToPrevStep, {
    ref: triggerGoToPrevStepRef
  });

  var triggerGoToNextStep = _extends({
    onClick: function onClick() {
      goToNextStep();
    }
  }, triggerDefaulGoToNextStep, {
    ref: triggerGoToNextStepRef
  });

  var triggerResetStep = _extends({
    onClick: function onClick() {
      reset();
    }
  }, triggerDefaulResetStep, {
    ref: triggerResetStepRef
  });

  return {
    currentStep: currentStep,
    goToStep: goToStep,
    goToPrevStep: goToPrevStep,
    goToNextStep: goToNextStep,
    isFirstStep: isFirstStep,
    isLastStep: isLastStep,
    reset: reset,
    canGoToPrevStep: canGoToPrevStep,
    canGoToNextStep: canGoToNextStep,
    triggerGoToPrevStep: triggerGoToPrevStep,
    triggerGoToNextStep: triggerGoToNextStep,
    triggerResetStep: triggerResetStep
  };
};

var useCarousel = function useCarousel(props) {
  if (props === void 0) {
    props = {
      maxSlide: 1,
      loop: true
    };
  }

  var _props = props,
      maxSlide = _props.maxSlide,
      loop = _props.loop,
      _props$activeSlide = _props.activeSlide,
      activeSlide = _props$activeSlide === void 0 ? 1 : _props$activeSlide,
      _props$triggerGoToPre = _props.triggerGoToPrevSlide,
      triggerGoToPrevSlide = _props$triggerGoToPre === void 0 ? {} : _props$triggerGoToPre,
      _props$triggerGoToNex = _props.triggerGoToNextSlide,
      triggerGoToNextSlide = _props$triggerGoToNex === void 0 ? {} : _props$triggerGoToNex;

  var _useStepper = useStepper({
    maxStep: maxSlide,
    loop: loop,
    activeStep: activeSlide,
    triggerGoToPrevStep: triggerGoToPrevSlide,
    triggerGoToNextStep: triggerGoToNextSlide
  }),
      currentStep = _useStepper.currentStep,
      goToStep = _useStepper.goToStep,
      goToPrevStep = _useStepper.goToPrevStep,
      goToNextStep = _useStepper.goToNextStep,
      isFirstStep = _useStepper.isFirstStep,
      isLastStep = _useStepper.isLastStep,
      canGoToPrevStep = _useStepper.canGoToPrevStep,
      canGoToNextStep = _useStepper.canGoToNextStep,
      triggerGoToPrevStep = _useStepper.triggerGoToPrevStep,
      triggerGoToNextStep = _useStepper.triggerGoToNextStep;

  return {
    currentSlide: currentStep,
    goToSlide: goToStep,
    goToPrevSlide: goToPrevStep,
    goToNextSlide: goToNextStep,
    isFirstSlide: isFirstStep,
    isLastSlide: isLastStep,
    canGoToPrevSlide: canGoToPrevStep,
    canGoToNextSlide: canGoToNextStep,
    triggerGoToPrevSlide: triggerGoToPrevStep,
    triggerGoToNextSlide: triggerGoToNextStep
  };
};

/**
 * useHasClickedOutside() - Returns true if the user has clicked outside of the given ref.
 */

function useHasClickedOutside(ref) {
  var _useState = react.useState(false),
      hasClickedOutside = _useState[0],
      setHasClickedOutside = _useState[1];

  react.useEffect(function () {
    /**
     * Alert if clicked on outside of element
     */
    function handleClickOutside(event) {
      if (ref.current && !ref.current.contains(event.target)) {
        setHasClickedOutside(true);
      }

      setHasClickedOutside(false);
    } // Bind the event listener


    document.addEventListener('mousedown', handleClickOutside);
    return function () {
      // Unbind the event listener on clean up
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, [ref]);
  return hasClickedOutside;
}

// Please do not use types off of a default export module or else Storybook Docs will suffer.
/**
 * useSwitch() - simulate a switch on/off logic.
 */

var useSwitch = function useSwitch(props) {
  if (props === void 0) {
    props = {};
  }

  var _props = props,
      _props$isOn = _props.isOn,
      isOnDefault = _props$isOn === void 0 ? false : _props$isOn,
      _props$disableTrigger = _props.disableTriggerClick,
      disableTriggerClick = _props$disableTrigger === void 0 ? false : _props$disableTrigger,
      _props$turnOnOnTrigge = _props.turnOnOnTriggerHover,
      turnOnOnTriggerHover = _props$turnOnOnTrigge === void 0 ? false : _props$turnOnOnTrigge,
      _props$turnOffOnTrigg = _props.turnOffOnTriggerLeave,
      turnOffOnTriggerLeave = _props$turnOffOnTrigg === void 0 ? false : _props$turnOffOnTrigg,
      _props$turnOffOnTarge = _props.turnOffOnTargetLeave,
      turnOffOnTargetLeave = _props$turnOffOnTarge === void 0 ? false : _props$turnOffOnTarge,
      _props$turnOffOnClick = _props.turnOffOnClickOutside,
      turnOffOnClickOutside = _props$turnOffOnClick === void 0 ? false : _props$turnOffOnClick;

  var _useState = react.useState(isOnDefault),
      isOn = _useState[0],
      setIsOn = _useState[1];

  var targetRef = react.useRef(null);
  var triggerRef = react.useRef(null);
  var hasClickedOutsideTarget = useHasClickedOutside(targetRef);
  var toggle = react.useCallback(function () {
    setIsOn(function (old) {
      return !old;
    });
  }, []);
  var turnOn = react.useCallback(function () {
    setIsOn(true);
  }, []);
  var turnOff = react.useCallback(function () {
    setIsOn(false);
  }, []);
  react.useEffect(function () {
    if (turnOffOnClickOutside && hasClickedOutsideTarget) {
      turnOff();
    }
  }, [hasClickedOutsideTarget]);
  var trigger = {
    onClick: react.useCallback(function () {
      !disableTriggerClick ? toggle() : null;
    }, [disableTriggerClick]),
    onMouseEnter: react.useCallback(function () {
      turnOnOnTriggerHover ? turnOn() : null;
    }, [turnOnOnTriggerHover]),
    onMouseLeave: react.useCallback(function () {
      turnOffOnTriggerLeave ? turnOff() : null;
    }, [turnOffOnTriggerLeave]),
    ref: triggerRef
  };
  var target = {
    onMouseLeave: react.useCallback(function () {
      turnOffOnTargetLeave ? turnOff() : null;
    }, [turnOffOnTargetLeave]),
    ref: targetRef
  };
  return {
    trigger: trigger,
    target: target,
    toggle: toggle,
    turnOn: turnOn,
    turnOff: turnOff,
    isOn: isOn
  };
};

// Please do not use types off of a default export module or else Storybook Docs will suffer.
/**
 * useDropdown() - Build your dropdown component that can be used to display a list of items.
 */

var useDropdown = function useDropdown(props) {
  if (props === void 0) {
    props = {};
  }

  var _props = props,
      _props$isOpen = _props.isOpen,
      isOpen = _props$isOpen === void 0 ? false : _props$isOpen,
      _props$disableTrigger = _props.disableTriggerClick,
      disableTriggerClick = _props$disableTrigger === void 0 ? false : _props$disableTrigger,
      _props$openListOnTrig = _props.openListOnTriggerHover,
      openListOnTriggerHover = _props$openListOnTrig === void 0 ? false : _props$openListOnTrig,
      _props$closeListOnLis = _props.closeListOnListLeave,
      closeListOnListLeave = _props$closeListOnLis === void 0 ? false : _props$closeListOnLis,
      _props$closeListOnCli = _props.closeListOnClickOutside,
      closeListOnClickOutside = _props$closeListOnCli === void 0 ? false : _props$closeListOnCli;

  var _useSwitch = useSwitch({
    isOn: isOpen,
    disableTriggerClick: disableTriggerClick,
    turnOnOnTriggerHover: openListOnTriggerHover,
    turnOffOnTargetLeave: closeListOnListLeave,
    turnOffOnClickOutside: closeListOnClickOutside
  }),
      trigger = _useSwitch.trigger,
      target = _useSwitch.target,
      toggle = _useSwitch.toggle,
      turnOn = _useSwitch.turnOn,
      turnOff = _useSwitch.turnOff,
      isOn = _useSwitch.isOn;

  return {
    trigger: trigger,
    list: target,
    toggleList: toggle,
    openList: turnOn,
    closeList: turnOff,
    isListOpen: isOn
  };
};

// Please do not use types off of a default export module or else Storybook Docs will suffer.
/**
 * useDropdown() - Build your dropdown component that can be used to display a list of items.
 */

var useDropdown$1 = function useDropdown(props) {
  if (props === void 0) {
    props = {};
  }

  var _props = props,
      _props$isVisible = _props.isVisible,
      isVisible = _props$isVisible === void 0 ? false : _props$isVisible,
      _props$showOnClick = _props.showOnClick,
      showOnClick = _props$showOnClick === void 0 ? false : _props$showOnClick,
      _props$hiddenTooltipO = _props.hiddenTooltipOnTriggerLeave,
      hiddenTooltipOnTriggerLeave = _props$hiddenTooltipO === void 0 ? true : _props$hiddenTooltipO,
      _props$closeTooltipOn = _props.closeTooltipOnClickOutside,
      closeTooltipOnClickOutside = _props$closeTooltipOn === void 0 ? false : _props$closeTooltipOn;

  var _useSwitch = useSwitch({
    isOn: isVisible,
    disableTriggerClick: !showOnClick,
    turnOnOnTriggerHover: !showOnClick,
    turnOffOnTriggerLeave: hiddenTooltipOnTriggerLeave,
    turnOffOnClickOutside: closeTooltipOnClickOutside
  }),
      trigger = _useSwitch.trigger,
      target = _useSwitch.target,
      toggle = _useSwitch.toggle,
      turnOn = _useSwitch.turnOn,
      turnOff = _useSwitch.turnOff,
      isOn = _useSwitch.isOn;

  return {
    trigger: trigger,
    tooltip: target,
    toggleTooltip: toggle,
    showTooltip: turnOn,
    hiddenTooltip: turnOff,
    isVisible: isOn
  };
};

var useProgressBar = function useProgressBar(props) {
  if (props === void 0) {
    props = {};
  }

  var _props = props,
      _props$percentuage = _props.percentuage,
      defaultPercentuage = _props$percentuage === void 0 ? 0 : _props$percentuage,
      _props$onChange = _props.onChange,
      onChange = _props$onChange === void 0 ? null : _props$onChange,
      _props$onComplete = _props.onComplete,
      onComplete = _props$onComplete === void 0 ? null : _props$onComplete;

  var _useState = react.useState(defaultPercentuage),
      percentuage = _useState[0],
      setPercentuage = _useState[1];

  var _useState2 = react.useState(false),
      isCompleted = _useState2[0],
      setIsCompleted = _useState2[1];

  var _useState3 = react.useState(false),
      isEmpty = _useState3[0],
      setIsEmpty = _useState3[1];

  react.useEffect(function () {
    if (onChange) {
      onChange(percentuage);
    }

    if (percentuage === 100 && onComplete) {
      onComplete(percentuage);
    }

    if (percentuage === 100) {
      setIsCompleted(true);
    } else {
      setIsCompleted(false);
    }

    if (percentuage === 0) {
      setIsEmpty(true);
    } else {
      setIsEmpty(false);
    }
  }, [percentuage]);

  var reset = function reset() {
    setPercentuage(defaultPercentuage);
  };

  var empty = function empty() {
    setPercentuage(0);
  };

  var complete = function complete() {
    setPercentuage(100);
  };

  var increment = function increment(value) {
    setPercentuage(function (prev) {
      return prev + value <= 100 ? prev + value : 100;
    });
  };

  var decrement = function decrement(value) {
    setPercentuage(function (prev) {
      return prev - value >= 0 ? prev - value : 0;
    });
  };

  return {
    percentuage: percentuage,
    increment: increment,
    decrement: decrement,
    reset: reset,
    complete: complete,
    empty: empty,
    isCompleted: isCompleted,
    isEmpty: isEmpty
  };
};

/**
 * useRate() - Build your rate component.
 */

var useRate = function useRate(props) {
  if (props === void 0) {
    props = {
      numRate: 5
    };
  }

  var _props = props,
      numRate = _props.numRate,
      _props$activeRate = _props.activeRate,
      activeRate = _props$activeRate === void 0 ? 0 : _props$activeRate,
      _props$allowClear = _props.allowClear,
      allowClear = _props$allowClear === void 0 ? true : _props$allowClear,
      _props$triggerClearRa = _props.triggerClearRate,
      triggerDefaultClearRate = _props$triggerClearRa === void 0 ? {} : _props$triggerClearRa;

  var _useState = react.useState(activeRate),
      currentRate = _useState[0],
      setCurrentRate = _useState[1];

  var _useState2 = react.useState(true),
      isFirstRate = _useState2[0],
      setIsFirstRate = _useState2[1];

  var _useState3 = react.useState(false),
      isLastRate = _useState3[0],
      setIsLastRate = _useState3[1];

  var _useState4 = react.useState(false),
      isReset = _useState4[0],
      setIsReset = _useState4[1];

  var triggerClearRateRef = react.useRef(null);
  var onChangeRate = react.useCallback(function (value) {
    if (value >= 1 && value <= numRate) {
      if (allowClear && value === currentRate) {
        setCurrentRate(0);
      } else {
        setCurrentRate(value);
      }
    }
  }, [numRate, currentRate, allowClear]);
  var clearRate = react.useCallback(function () {
    if (allowClear) {
      setCurrentRate(0);
    } else {
      setCurrentRate(1);
    }
  }, [currentRate, allowClear]);
  react.useEffect(function () {
    setIsFirstRate(false);
    setIsLastRate(false);
    setIsReset(false);

    if (currentRate === 1) {
      setIsFirstRate(true);
    }

    if (currentRate === numRate) {
      setIsLastRate(true);
    }

    if (currentRate === 0) {
      setIsReset(true);
    }

    return function () {
      setIsFirstRate(true);
      setIsLastRate(false);
      setIsReset(false);
    };
  }, [currentRate]);

  var triggerClearRate = _extends({
    onClick: function onClick() {
      clearRate();
    }
  }, triggerDefaultClearRate, {
    ref: triggerClearRateRef
  });

  return {
    currentRate: currentRate,
    onChangeRate: onChangeRate,
    isFirstRate: isFirstRate,
    isLastRate: isLastRate,
    isReset: isReset,
    clearRate: clearRate,
    triggerClearRate: triggerClearRate
  };
};

var useAccordion = function useAccordion(props) {
  if (props === void 0) {
    props = {};
  }

  var _props = props,
      _props$data = _props.data,
      defaultData = _props$data === void 0 ? [] : _props$data,
      _props$onChange = _props.onChange,
      onChangePanelStatus = _props$onChange === void 0 ? null : _props$onChange,
      _props$expandAll = _props.expandAll,
      expandAll = _props$expandAll === void 0 ? false : _props$expandAll,
      _props$expandByIndexe = _props.expandByIndexes,
      expandByIndexes = _props$expandByIndexe === void 0 ? [] : _props$expandByIndexe;

  var isExpandedByDefault = function isExpandedByDefault(indexesArray, currentIndex) {
    if (indexesArray.includes(currentIndex)) return true;
    return false;
  };

  var onChangePanelStatusHandler = function onChangePanelStatusHandler(indexElement) {
    var _arrayCopy$ps;

    var arrayCopy = [].concat(accordion);
    var ps = arrayCopy.findIndex(function (el) {
      return el.index === indexElement;
    });
    arrayCopy[ps]['isExpanded'] = !((_arrayCopy$ps = arrayCopy[ps]) != null && _arrayCopy$ps.isExpanded);
    return setAccordion(arrayCopy);
  };

  var getCurrentOpenPanels = function getCurrentOpenPanels(accordionState) {
    return [].concat(accordionState).filter(function (el) {
      return el.isExpanded;
    });
  };

  var _useState = react.useState([]),
      currentOpenPanels = _useState[0],
      setCurrentOpenPanels = _useState[1];

  var _useState2 = react.useState(function () {
    return defaultData ? defaultData.map(function (el, index) {
      return _extends({}, el, {
        index: index,
        isExpanded: expandAll ? expandAll : isExpandedByDefault(expandByIndexes, index) ? true : false,
        trigger: function trigger(indexElement) {
          return {
            onClick: function onClick() {
              return onChangePanelStatusHandler(indexElement);
            }
          };
        }
      });
    }) : [];
  }),
      accordion = _useState2[0],
      setAccordion = _useState2[1];

  react.useEffect(function () {
    if (onChangePanelStatus) {
      onChangePanelStatus(accordion);
    }

    if (accordion.length > 0) {
      setCurrentOpenPanels(getCurrentOpenPanels(accordion));
    }
  }, [accordion]);
  return {
    accordion: accordion,
    currentOpenPanels: currentOpenPanels
  };
};

var useTab = function useTab(props) {
  if (props === void 0) {
    props = {
      numTabs: 3
    };
  }

  var _props = props,
      numTabs = _props.numTabs,
      _props$activeTab = _props.activeTab,
      activeTab = _props$activeTab === void 0 ? 1 : _props$activeTab,
      _props$triggerGoToPre = _props.triggerGoToPrevTab,
      triggerGoToPrevTab = _props$triggerGoToPre === void 0 ? {} : _props$triggerGoToPre,
      _props$triggerGoToNex = _props.triggerGoToNextTab,
      triggerGoToNextTab = _props$triggerGoToNex === void 0 ? {} : _props$triggerGoToNex;

  var _useStepper = useStepper({
    maxStep: numTabs,
    activeStep: activeTab,
    triggerGoToPrevStep: triggerGoToPrevTab,
    triggerGoToNextStep: triggerGoToNextTab
  }),
      currentStep = _useStepper.currentStep,
      goToStep = _useStepper.goToStep,
      goToPrevStep = _useStepper.goToPrevStep,
      goToNextStep = _useStepper.goToNextStep,
      isFirstStep = _useStepper.isFirstStep,
      isLastStep = _useStepper.isLastStep,
      canGoToPrevStep = _useStepper.canGoToPrevStep,
      canGoToNextStep = _useStepper.canGoToNextStep,
      triggerGoToPrevStep = _useStepper.triggerGoToPrevStep,
      triggerGoToNextStep = _useStepper.triggerGoToNextStep;

  return {
    currentTab: currentStep,
    goToTab: goToStep,
    goToPrevTab: goToPrevStep,
    goToNextTab: goToNextStep,
    isFirstTab: isFirstStep,
    isLastTab: isLastStep,
    canGoToPrevTab: canGoToPrevStep,
    canGoToNextTab: canGoToNextStep,
    triggerGoToPrevTab: triggerGoToPrevStep,
    triggerGoToNextTab: triggerGoToNextStep
  };
};

var usePagination = function usePagination(props) {
  if (props === void 0) {
    props = {
      numPages: 3
    };
  }

  var _props = props,
      numPages = _props.numPages,
      _props$activePage = _props.activePage,
      activePage = _props$activePage === void 0 ? 1 : _props$activePage,
      _props$triggerGoToPre = _props.triggerGoToPrevPage,
      triggerGoToPrevPage = _props$triggerGoToPre === void 0 ? {} : _props$triggerGoToPre,
      _props$triggerGoToNex = _props.triggerGoToNextPage,
      triggerGoToNextPage = _props$triggerGoToNex === void 0 ? {} : _props$triggerGoToNex,
      _props$triggerGoToFir = _props.triggerGoToFirstPage,
      triggerDefaultGoToFirstPage = _props$triggerGoToFir === void 0 ? {} : _props$triggerGoToFir,
      _props$triggerGoToLas = _props.triggerGoToLastPage,
      triggerDefaultGoToLastPage = _props$triggerGoToLas === void 0 ? {} : _props$triggerGoToLas;

  var _useStepper = useStepper({
    maxStep: numPages,
    activeStep: activePage,
    triggerGoToPrevStep: triggerGoToPrevPage,
    triggerGoToNextStep: triggerGoToNextPage
  }),
      currentStep = _useStepper.currentStep,
      goToStep = _useStepper.goToStep,
      goToPrevStep = _useStepper.goToPrevStep,
      goToNextStep = _useStepper.goToNextStep,
      isFirstStep = _useStepper.isFirstStep,
      isLastStep = _useStepper.isLastStep,
      canGoToPrevStep = _useStepper.canGoToPrevStep,
      canGoToNextStep = _useStepper.canGoToNextStep,
      triggerGoToPrevStep = _useStepper.triggerGoToPrevStep,
      triggerGoToNextStep = _useStepper.triggerGoToNextStep;

  var triggerGoToFirstPageRef = react.useRef(null);
  var triggerGoToLastPageRef = react.useRef(null);

  var triggerGoToFirstPage = _extends({
    onClick: function onClick() {
      goToStep(1);
    }
  }, triggerDefaultGoToFirstPage, {
    ref: triggerGoToFirstPageRef
  });

  var triggerGoToLastPage = _extends({
    onClick: function onClick() {
      goToStep(numPages);
    }
  }, triggerDefaultGoToLastPage, {
    ref: triggerGoToLastPageRef
  });

  return {
    currentPage: currentStep,
    goToPage: goToStep,
    goToPrevPage: goToPrevStep,
    goToNextPage: goToNextStep,
    isFirstPage: isFirstStep,
    isLastPage: isLastStep,
    canGoToPrevPage: canGoToPrevStep,
    canGoToNextPage: canGoToNextStep,
    triggerGoToPrevPage: triggerGoToPrevStep,
    triggerGoToNextPage: triggerGoToNextStep,
    triggerGoToFirstPage: triggerGoToFirstPage,
    triggerGoToLastPage: triggerGoToLastPage
  };
};

var _excluded = ["triggerFlow"];

var useMediaQuery = function useMediaQuery(props) {
  if (props === void 0) {
    props = {};
  }

  var _props = props,
      _props$breakpoints = _props.breakpoints,
      breakpointsDefault = _props$breakpoints === void 0 ? [] : _props$breakpoints;

  var getBreakPoint = function getBreakPoint(obj, getValue) {
    if (getValue === void 0) {
      getValue = true;
    }

    var allBreaks = ['xs', 'sm', 'md', 'lg', 'xl'];
    var returned;

    for (var key in obj) {
      if (allBreaks.includes(key) && getValue) {
        returned = obj[key];
      } else {
        returned = key;
      }

      break;
    }

    return returned;
  };

  var buildMediaQueryForEachObject = function buildMediaQueryForEachObject() {
    var obj = {};
    var min = 'min';
    var max = 'max';
    breakpointsDefault.forEach(function (el) {
      var triggerFlow = el.triggerFlow,
          rest = _objectWithoutPropertiesLoose(el, _excluded);

      var triggerMedia = triggerFlow === 'up' ? min : max;
      obj["" + getBreakPoint(rest, false)] = window.matchMedia("(" + triggerMedia + "-width: " + getBreakPoint(rest) + ")").matches;
    });
    return obj;
  };

  var _useState = react.useState(function () {
    return buildMediaQueryForEachObject();
  }),
      media = _useState[0];

  react.useEffect(function () {}, [media['xl']]);
  return {
    breakpointsDefault: breakpointsDefault,
    media: media
  };
};

exports.useAccordion = useAccordion;
exports.useCarousel = useCarousel;
exports.useDropdown = useDropdown;
exports.useHasClickedOutside = useHasClickedOutside;
exports.useMediaQuery = useMediaQuery;
exports.usePagination = usePagination;
exports.useProgressBar = useProgressBar;
exports.useRate = useRate;
exports.useStepper = useStepper;
exports.useSwitch = useSwitch;
exports.useTab = useTab;
exports.useTooltip = useDropdown$1;
//# sourceMappingURL=react-headless-hooks.cjs.development.js.map
